body {
  background-color: #fff;
  margin: 1em auto;
  max-width: 800px;
  overflow: visible;
  padding-left: 2em;
  padding-right: 2em;
  font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  font-size: 16px;
  line-height: 24px;
  color: #333;
}

h1.title {
  text-align: center;
  font-weight: 600;
}

h4.author {
  text-align: center;
}

h4.date {
  text-align: center;
}

#TOC {
  clear: both;
  margin: 0 0 10px 0px;
  padding: 15px;
  width: 770px;
  border: 1px solid #CCCCCC;
  border-radius: 5px;
  background-color: #f6f6f6;
  font-size: 16px;
  line-height: 1.5;
}

#TOC .toctitle {
  font-weight: bold;
  font-size: 16px;
  margin-left: 5px;
}

#TOC ul {
  padding-left: 50px;
  margin-left: -1.5em;
  margin-top: 5px;
  margin-bottom: 5px;
}

#TOC ul ul {
  margin-left: -2em;
}

#TOC li {
  line-height: 20px;
}

table {
  margin: 1em auto;
  border-width: 1px;
  border-color: #DDDDDD;
  border-style: outset;
  border-collapse: collapse;
}

table th {
  border-width: 2px;
  padding: 5px;
  border-style: inset;
}

table td {
  border-width: 1px;
  border-style: inset;
  line-height: 18px;
  padding: 5px 5px;
}

table,
table th,
table td {
  border-left-style: none;
  border-right-style: none;
}

table thead,
table tr.even {
  background-color: #f7f7f7;
}

p {
  margin: 0.5em 0;
}

blockquote {
  background-color: #f6f6f6;
  padding: 1em 2em;
}

hr {
  border-style: solid;
  border: none;
  border-top: 1px solid #777;
  margin: 28px 0;
}

dl {
  margin-left: 0;
}

dl dd {
  margin-bottom: 13px;
  margin-left: 13px;
}

dl dt {
  font-weight: bold;
}

ul {
  margin-top: 0;
}

ul li {
  list-style: circle outside;
}

ul ul {
  margin-bottom: 0;
}

pre,
code {
  background-color: #f7f7f7;
  border-radius: 5px;
  color: #333;
  white-space: pre-wrap;
  /* Wrap long lines */
}

pre {
  border-radius: 5px;
  margin: 5px 0px 10px 0px;
  padding: 10px;
}

pre:not([class]) {
  background-color: #f7f7f7;
}

code {
  font-family: Menlo, Monaco, "Lucida Console", Consolas, "Courier New", monospace;
  font-size: 85%;
}

p>code,
li>code {
  padding: 2px 0px;
}

div.figure {
  text-align: center;
}

img {
  background-color: #FFFFFF;
  padding: 2px;
  border: 1px solid #DDDDDD;
  border-radius: 3px;
  border: 1px solid #CCCCCC;
  margin: 0 5px;
}

h1 {
  margin-top: 25px;
  font-size: 32px;
  line-height: 40px;
  font-weight: 600;
}

h2 {
  border-bottom: 2px solid #f7f7f7;
  padding-top: 10px;
  padding-bottom: 2px;
  font-size: 145%;
}

h3 {
  border-bottom: 1px solid #f7f7f7;
  padding-top: 10px;
  font-size: 120%;
}

h4 {
  margin-left: 8px;
  font-size: 110%;
  font-weight: normal;
}

em {
  font-style: normal;
}

emph {
  font-style: oblique;
}

h5,
h6 {
  border-bottom: 1px solid #ccc;
  font-size: 105%;
}

a {
  color: #123d79;
  text-decoration: none;
}

a:hover {
  color: #007CC3;
}

a:visited {
  color: #581858;
}

a:visited:hover {
  color: #007CC3;
}


/* code highlight theme: highlight.js - tomorrow
   http://jmblog.github.io/color-themes-for-highlightjs/tomorrow/
*/

code>span.kw {
  color: #4271ae;
}


/* Keyword */

code>span.dt {
  color: #c82829;
}


/* DataType */

code>span.dv {
  color: #f5871f;
}


/* DecVal (decimal values) */

code>span.bn {
  color: #718c00;
}


/* BaseN */

code>span.fl {
  color: #718c00;
}


/* Float */

code>span.ch {
  color: #718c00;
}


/* Char */

code>span.st {
  color: #718c00;
}


/* String */

code>span.co {
  color: #8e908c;
}


/* Comment */

code>span.ot {
  color: #4d4d4c;
}


/* OtherToken */

code>span.al {
  color: #ff0000;
}


/* AlertToken */

code>span.fu {
  color: #4271ae;
}


/* Function calls */

code>span.er {
  color: #a61717;
}


/* ErrorTok */


/* centering images */

img {
  display: block;
  margin: 0 auto;
}